@@ -7,7 +7,7 @@ use Carp;
 use Data::Validator;
 use Mouse;
 use Mouse::Util::TypeConstraints;
-use Log::Minimal;
+use Log::Minimal env_debug => 'PROCLET_DEBUG';
 use IO::Select;
 use Term::ANSIColor;
 
@@ -17,7 +17,7 @@ subtype 'ServiceProcs'
 
 no Mouse::Util::TypeConstraints;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 has '_services' => (
     is => 'ro',
@@ -115,7 +115,6 @@ sub run {
         on_child_reap => sub {
             my ( $pm, $exit_pid, $status ) = @_;
             local $Log::Minimal::AUTODUMP = 1;
-            local $Log::Minimal::ENV_DEBUG = 'PROCLET_DEBUG';
             debugf "[Proclet] on child reap: exit_pid => %s status => %s, service => %s", 
                 $exit_pid, $status, exists $pid2service{$exit_pid} ? $pid2service{$exit_pid} : 'undefined';
             if ( exists $pid2service{$exit_pid} ) {
@@ -131,7 +130,6 @@ sub run {
 
         before_fork => sub {
             local $Log::Minimal::AUTODUMP = 1;
-            local $Log::Minimal::ENV_DEBUG = 'PROCLET_DEBUG';
             debugf "[Proclet] before_fork: running => %s", \%running;
             my $pm = shift;
             if ( ! exists $running{$LOGGER} ) {
@@ -150,7 +148,6 @@ sub run {
         after_fork => sub {
             my ($pm, $pid) = @_;
             local $Log::Minimal::AUTODUMP = 1;
-            local $Log::Minimal::ENV_DEBUG = 'PROCLET_DEBUG';
             if ( defined $next ) {
                 debugf "[Proclet] child start: sid =>%s", $next;
                 $pid2service{$pid} = $next;
@@ -183,7 +180,6 @@ sub run {
             }
             else {
                 local $Log::Minimal::AUTODUMP = 1;
-                local $Log::Minimal::ENV_DEBUG = 'PROCLET_DEBUG';
                 debugf "[Proclet] child (pid=>%s) start but next is undefined",$$;
             }
         });
@@ -203,7 +199,6 @@ sub log_worker {
     my $self = shift;
     sub {
         local $Log::Minimal::AUTODUMP = 1;
-        local $Log::Minimal::ENV_DEBUG = 'PROCLET_DEBUG';
         my $services = shift;
         my %fileno2sid;
         my $s = IO::Select->new();
